==> CGSocialApp-1.1.10.tar.gz: CGSocialApp/function.admin_default_templates_tab.php <==
<?php
#BEGIN_LICENSE
#-------------------------------------------------------------------------
# Module: CGSocialApp (c) 2012 by Robert Campbell 
#         (calguy1000@cmsmadesimple.org)
# 
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in its admin 
# section that the site was built with CMS Made simple.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
#END_LICENSE
if( !isset($gCms) ) exit;
if( !$this->CheckPermission('Modify Templates') ) return;

echo cge_template_admin::get_start_template_form($this,$id,'',
						 'default_list_checkin_template_contents',
						 'admin_templates','default_templates',
						 $this->Lang('sysdflt_list_checkins_template'),
						 'orig_list_checkins.tpl');

echo cge_template_admin::get_start_template_form($this,$id,'',
						 'default_list_activities_template_contents',
						 'admin_templates','default_templates',
						 $this->Lang('sysdflt_list_activities_template'),
						 'orig_list_activities.tpl');

echo cge_template_admin::get_start_template_form($this,$id,'',
						 'default_view_activity_template_contents',
						 'admin_templates','default_templates',
						 $this->Lang('sysdflt_view_activity_template'),
						 'orig_view_activity.tpl');

#
# EOF
#
?>

==> CGSocialApp-1.3.1.tar.gz: CGSocialApp/function.admin_default_templates_tab.php <==
<?php
#BEGIN_LICENSE
#-------------------------------------------------------------------------
# Module: CGSocialApp (c) 2012 by Robert Campbell 
#         (calguy1000@cmsmadesimple.org)
# 
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in its admin 
# section that the site was built with CMS Made simple.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
#END_LICENSE
if( !isset($gCms) ) exit;
if( !$this->CheckPermission('Modify Templates') ) return;

echo cge_template_admin::get_start_template_form($this,$id,'',
						 'default_add_checkin_template_contents',
						 'admin_templates','default_templates',
						 $this->Lang('sysdflt_add_checkin_template'),
						 'orig_add_checkin.tpl');

echo cge_template_admin::get_start_template_form($this,$id,'',
						 'default_list_checkin_template_contents',
						 'admin_templates','default_templates',
						 $this->Lang('sysdflt_list_checkins_template'),
						 'orig_list_checkins.tpl');

echo cge_template_admin::get_start_template_form($this,$id,'',
						 'default_view_checkin_template_contents',
						 'admin_templates','default_templates',
						 $this->Lang('sysdflt_view_checkin_template'),
						 'orig_view_checkin.tpl');

echo cge_template_admin::get_start_template_form($this,$id,'',
						 'default_list_activities_template_contents',
						 'admin_templates','default_templates',
						 $this->Lang('sysdflt_list_activities_template'),
						 'orig_list_activities.tpl');

echo cge_template_admin::get_start_template_form($this,$id,'',
						 'default_view_activity_template_contents',
						 'admin_templates','default_templates',
						 $this->Lang('sysdflt_view_activity_template'),
						 'orig_view_activity.tpl');

echo cge_template_admin::get_start_template_form($this,$id,'',
						 'default_friendreq_template_contents',
						 'admin_templates','default_templates',
						 $this->Lang('sysdflt_friendreq_template'),
						 'orig_friendreq.tpl');

echo cge_template_admin::get_start_template_form($this,$id,'',
						 'default_friendreqlist_template_contents',
						 'admin_templates','default_templates',
						 $this->Lang('sysdflt_friendreqlist_template'),
						 'orig_friendreqlist.tpl');

echo cge_template_admin::get_start_template_form($this,$id,'',
						 'default_badgesummary_template_contents',
						 'admin_templates','default_templates',
						 $this->Lang('sysdflt_badgesummary_template'),
						 'orig_badge_summary.tpl');

echo cge_template_admin::get_start_template_form($this,$id,'',
						 'default_badgedetail_template_contents',
						 'admin_templates','default_templates',
						 $this->Lang('sysdflt_badgedetail_template'),
						 'orig_badge_detail.tpl');

echo cge_template_admin::get_start_template_form($this,$id,'',
						 'default_leaderboardsummary_template_contents',
						 'admin_templates','default_templates',
						 $this->Lang('sysdflt_leaderboardsummary_template'),
						 'orig_leaderboard_summary.tpl');

echo cge_template_admin::get_start_template_form($this,$id,'',
						 'default_leaderboarddetail_template_contents',
						 'admin_templates','default_templates',
						 $this->Lang('sysdflt_leaderboarddetail_template'),
						 'orig_leaderboard_detail.tpl');

#
# EOF
#
?>
